from typing import List as _List

from pywttr_models import base as _base


class WeatherItem(_base.WeatherItem):
    hourly: _List[_base.HourlyItem]


class Model(_base.Model):
    current_condition: _List[_base.CurrentConditionItem]
    weather: _List[WeatherItem]



from pywttr_models import (
    af,
    am,
    ar,
    az,
    base,
    be,
    bg,
    bn,
    bs,
    ca,
    cs,
    cy,
    da,
    de,
    el,
    en,
    eo,
    es,
    et,
    eu,
    fa,
    fi,
    fr,
    fy,
    ga,
    he,
    hi,
    hr,
    hu,
    hy,
    ia,
    id,
    is_,
    it,
    ja,
    jv,
    kk,
    ko,
    lt,
    lv,
    mg,
    mk,
    mr,
    nb,
    nl,
    nn,
    oc,
    pl,
    pt,
    pt_br,
    ro,
    ru,
    sk,
    sl,
    sr,
    sr_lat,
    sv,
    ta,
    te,
    th,
    tr,
    uk,
    uz,
    vi,
    zh,
    zh_cn,
    zh_tw,
    zu,
)

__all__ = (
    "af",
    "am",
    "ar",
    "az",
    "base",
    "be",
    "bg",
    "bn",
    "bs",
    "ca",
    "cs",
    "cy",
    "da",
    "de",
    "el",
    "en",
    "eo",
    "es",
    "et",
    "eu",
    "fa",
    "fi",
    "fr",
    "fy",
    "ga",
    "he",
    "hi",
    "hr",
    "hu",
    "hy",
    "ia",
    "id",
    "is_",
    "it",
    "ja",
    "jv",
    "kk",
    "ko",
    "lt",
    "lv",
    "mg",
    "mk",
    "mr",
    "nb",
    "nl",
    "nn",
    "oc",
    "pl",
    "pt",
    "pt_br",
    "ro",
    "ru",
    "sk",
    "sl",
    "sr",
    "sr_lat",
    "sv",
    "ta",
    "te",
    "th",
    "tr",
    "uk",
    "uz",
    "vi",
    "zh",
    "zh_cn",
    "zh_tw",
    "zu",
)



from typing import List as _List

from pydantic import BaseModel as _BaseModel
from pydantic import Field as _Field


class LangItem(_BaseModel):
    value: str


class WeatherDescItem(_BaseModel):
    value: str


class WeatherIconUrlItem(_BaseModel):
    value: str


class CurrentConditionItem(_BaseModel):
    feels_like_c: str = _Field(..., alias="FeelsLikeC")
    feels_like_f: str = _Field(..., alias="FeelsLikeF")
    cloudcover: str
    humidity: str
    local_obs_date_time: str = _Field(..., alias="localObsDateTime")
    observation_time: str
    precip_inches: str = _Field(..., alias="precipInches")
    precip_mm: str = _Field(..., alias="precipMM")
    pressure: str
    pressure_inches: str = _Field(..., alias="pressureInches")
    temp_c: str = _Field(..., alias="temp_C")
    temp_f: str = _Field(..., alias="temp_F")
    uv_index: str = _Field(..., alias="uvIndex")
    visibility: str
    visibility_miles: str = _Field(..., alias="visibilityMiles")
    weather_code: str = _Field(..., alias="weatherCode")
    weather_desc: _List[WeatherDescItem] = _Field(..., alias="weatherDesc")
    weather_icon_url: _List[WeatherIconUrlItem] = _Field(
        ..., alias="weatherIconUrl"
    )
    winddir16_point: str = _Field(..., alias="winddir16Point")
    winddir_degree: str = _Field(..., alias="winddirDegree")
    windspeed_kmph: str = _Field(..., alias="windspeedKmph")
    windspeed_miles: str = _Field(..., alias="windspeedMiles")


class AreaNameItem(_BaseModel):
    value: str


class CountryItem(_BaseModel):
    value: str


class RegionItem(_BaseModel):
    value: str


class WeatherUrlItem(_BaseModel):
    value: str


class NearestAreaItem(_BaseModel):
    area_name: _List[AreaNameItem] = _Field(..., alias="areaName")
    country: _List[CountryItem]
    latitude: str
    longitude: str
    population: str
    region: _List[RegionItem]
    weather_url: _List[WeatherUrlItem] = _Field(..., alias="weatherUrl")


class RequestItem(_BaseModel):
    query: str
    type: str


class AstronomyItem(_BaseModel):
    moon_illumination: str
    moon_phase: str
    moonrise: str
    moonset: str
    sunrise: str
    sunset: str


class WeatherDescItem1(_BaseModel):
    value: str


class WeatherIconUrlItem1(_BaseModel):
    value: str


class HourlyItem(_BaseModel):
    dew_point_c: str = _Field(..., alias="DewPointC")
    dew_point_f: str = _Field(..., alias="DewPointF")
    feels_like_c: str = _Field(..., alias="FeelsLikeC")
    feels_like_f: str = _Field(..., alias="FeelsLikeF")
    heat_index_c: str = _Field(..., alias="HeatIndexC")
    heat_index_f: str = _Field(..., alias="HeatIndexF")
    wind_chill_c: str = _Field(..., alias="WindChillC")
    wind_chill_f: str = _Field(..., alias="WindChillF")
    wind_gust_kmph: str = _Field(..., alias="WindGustKmph")
    wind_gust_miles: str = _Field(..., alias="WindGustMiles")
    chanceoffog: str
    chanceoffrost: str
    chanceofhightemp: str
    chanceofovercast: str
    chanceofrain: str
    chanceofremdry: str
    chanceofsnow: str
    chanceofsunshine: str
    chanceofthunder: str
    chanceofwindy: str
    cloudcover: str
    humidity: str
    precip_inches: str = _Field(..., alias="precipInches")
    precip_mm: str = _Field(..., alias="precipMM")
    pressure: str
    pressure_inches: str = _Field(..., alias="pressureInches")
    temp_c: str = _Field(..., alias="tempC")
    temp_f: str = _Field(..., alias="tempF")
    time: str
    uv_index: str = _Field(..., alias="uvIndex")
    visibility: str
    visibility_miles: str = _Field(..., alias="visibilityMiles")
    weather_code: str = _Field(..., alias="weatherCode")
    weather_desc: _List[WeatherDescItem1] = _Field(..., alias="weatherDesc")
    weather_icon_url: _List[WeatherIconUrlItem1] = _Field(
        ..., alias="weatherIconUrl"
    )
    winddir16_point: str = _Field(..., alias="winddir16Point")
    winddir_degree: str = _Field(..., alias="winddirDegree")
    windspeed_kmph: str = _Field(..., alias="windspeedKmph")
    windspeed_miles: str = _Field(..., alias="windspeedMiles")


class WeatherItem(_BaseModel):
    astronomy: _List[AstronomyItem]
    avgtemp_c: str = _Field(..., alias="avgtempC")
    avgtemp_f: str = _Field(..., alias="avgtempF")
    date: str
    maxtemp_c: str = _Field(..., alias="maxtempC")
    maxtemp_f: str = _Field(..., alias="maxtempF")
    mintemp_c: str = _Field(..., alias="mintempC")
    mintemp_f: str = _Field(..., alias="mintempF")
    sun_hour: str = _Field(..., alias="sunHour")
    total_snow_cm: str = _Field(..., alias="totalSnow_cm")
    uv_index: str = _Field(..., alias="uvIndex")


class Model(_BaseModel):
    nearest_area: _List[NearestAreaItem]
    request: _List[RequestItem]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pywttr_models']

package_data = \
{'': ['*']}

install_requires = \
['pydantic>=1.9,<2.0']

setup_kwargs = {
    'name': 'pywttr-models',
    'version': '0.1.5',
    'description': 'Pydantic models for pywttr and aiopywttr',
    'long_description': '# pywttr-models\n\n[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://github.com/monosans/pywttr-models/blob/main/LICENSE)\n\n[Pydantic](https://github.com/samuelcolvin/pydantic) models for [pywttr](https://github.com/monosans/pywttr) and [aiopywttr](https://github.com/monosans/aiopywttr).\n\n## Usage for type annotation\n\n```python\nimport pywttr_models\n\n\ndef do_something(model: pywttr_models.en.Model):\n    ...\n```\n\nOther languages may also be used instead of `en`. For a complete list of supported languages, see the [file names](https://github.com/monosans/pywttr-models/tree/main/pywttr-models) or follow the code completion in your IDE.\n\n## Documentation\n\nThere is no documentation, just follow the code completion from your IDE.\n\nRecommended IDEs:\n\n- [Visual Studio Code](https://code.visualstudio.com) (with [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python))\n- [PyCharm](https://jetbrains.com/pycharm)\n',
    'author': 'monosans',
    'author_email': 'hsyqixco@protonmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/monosans/pywttr-models',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



from typing import List as _List

from pywttr_models import base as _base


class CurrentConditionItem(_base.CurrentConditionItem):
    lang_mr: _List[_base.LangItem]


class HourlyItem(_base.HourlyItem):
    lang_mr: _List[_base.LangItem]


class WeatherItem(_base.WeatherItem):
    hourly: _List[HourlyItem]


class Model(_base.Model):
    current_condition: _List[CurrentConditionItem]
    weather: _List[WeatherItem]
